@@ -83,7 +83,7 @@ def process_config_local(config, arg, args, flags):
 
 arg_flags = ArgFlag()
 arg = Arg(arg_flags)
-flags = arg_flags.STD_WRITE | arg_flags.WALLET | arg_flags.CREATE | arg_flags.VALUE | arg_flags.TAB
+flags = arg_flags.STD_WRITE | arg_flags.WALLET | arg_flags.VALUE | arg_flags.TAB
 
 argparser = chainlib.eth.cli.ArgumentParser()
 argparser = process_args(argparser, arg, flags)
@@ -144,7 +144,7 @@ def main():
      
     (tx_hash_hex, o) = g.create(
             settings.get('SENDER_ADDRESS'),
-            settings.get('RECIPIENT'),
+            recipient,
             settings.get('VALUE'),
             data=settings.get('DATA'),
             id_generator=settings.get('RPC_ID_GENERATOR'),
